@@ -11,7 +11,7 @@ use LWP::UserAgent;
 use Menlo::Index::MetaCPAN;
 use URI::cpan;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -66,8 +66,7 @@ sub run {
 		'package' => $self->{'_module_name'},
 	});
 	if (! defined $res) {
-		print STDERR "Module '".$self->{'_module_name'}."' doesn't exist.";
-		return 1;
+		err "Module '".$self->{'_module_name'}."' doesn't exist.";
 	}
 
 	# Download dist.
@@ -87,7 +86,7 @@ sub run {
 	my $dist_file = ($u->path_segments)[-1];
 	barf($dist_file, $dist_res->decoded_content);
 
-	print "'$res->{'download_uri'}' was downloaded.\n";
+	print "Package on '$res->{'download_uri'}' was downloaded.\n";
 	
 	return 0;
 }
@@ -128,6 +127,19 @@ Run.
 
 Returns 1 for error, 0 for success.
 
+=head1 ERRORS
+
+ new():
+         From Class::Utils::set_params():
+                 Unknown parameter '%s'.
+         Parameter 'lwp_user_agent' must be a LWP::UserAgent instance.
+
+ run():
+         Cannot download '%s'.
+         Module '%s' doesn't exist.
+         Value 'download_uri' doesn't exist.
+         Value 'uri' doesn't exist.
+
 =head1 EXAMPLE
 
  use strict;
@@ -144,6 +156,7 @@ Returns 1 for error, 0 for success.
  exit App::CPAN::Get->new->run;
 
  # Output like:
+ # Package on 'http://cpan.metacpan.org/authors/id/S/SK/SKIM/App-Pod-Example-0.19.tar.gz' was downloaded.
 
 =head1 DEPENDENCIES
 
@@ -173,6 +186,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
